@@ -14,30 +14,39 @@ import logging
 logger = logging.getLogger(__name__)
 TMUXP_DIR = os.path.join(os.path.dirname(__file__), '.tmuxp')
 
+
 sampleconfigdict = {
     'session_name': 'sampleconfig',
     'start_directory': '~',
-    'windows': [{
-        'window_name': 'editor',
-        'panes': [
-            {
-                'start_directory': '~', 'shell_command': ['vim'],
+    'windows': [
+        {
+            'window_name': 'editor',
+            'panes': [
+                {
+                    'start_directory': '~',
+                    'shell_command': ['vim'],
                 },  {
-                'shell_command': ['cowsay "hey"']
+                    'shell_command': ['cowsay "hey"']
+                },
+            ],
+            'layout': 'main-verticle'
+        },
+        {
+            'window_name': 'logging',
+            'panes': [{
+                'shell_command': ['tail -F /var/log/syslog'],
+                'start_directory':'/var/log'
+            }]
+        },
+        {
+            'options': {
+                'automatic_rename': True,
             },
-        ],
-        'layout': 'main-verticle'},
-        {'window_name': 'logging', 'panes': [
-         {'shell_command': ['tail -F /var/log/syslog'],
-          'start_directory':'/var/log'}
-         ]}, {
-             'options': {
-               'automatic_rename': True,
-             },
             'panes': [
                 {'shell_command': ['htop']}
             ]
-        }]
+        }
+    ]
 }
 
 
@@ -149,7 +158,7 @@ class ExpandTest(unittest.TestCase):
                 ]
             },
             {
-                'options': { 'automatic_rename': True, },
+                'options': {'automatic_rename': True, },
                 'panes': [
                     {'shell_command': 'htop'},
                     'vim',
@@ -160,17 +169,19 @@ class ExpandTest(unittest.TestCase):
     after_config = {
         'session_name': 'sampleconfig',
         'start_directory': '~',
-        'windows': [{
-            'shell_command': ['top'],
-            'window_name': 'editor',
-            'panes': [
-                {
-                    'start_directory': '~', 'shell_command': ['vim'],
+        'windows': [
+            {
+                'shell_command': ['top'],
+                'window_name': 'editor',
+                'panes': [
+                    {
+                        'start_directory': '~', 'shell_command': ['vim'],
                     },  {
-                    'shell_command': ['cowsay "hey"']
-                },
-            ],
-            'layout': 'main-verticle'},
+                        'shell_command': ['cowsay "hey"']
+                    },
+                ],
+                'layout': 'main-verticle'
+            },
             {
                 'window_name': 'logging',
                 'panes': [
@@ -179,12 +190,13 @@ class ExpandTest(unittest.TestCase):
                 ]
             },
             {
-                'options': { 'automatic_rename': True },
+                'options': {'automatic_rename': True},
                 'panes': [
                     {'shell_command': ['htop']},
                     {'shell_command': ['vim']}
                 ]
-            }]
+            }
+        ]
     }
 
     def test_config(self):
@@ -203,17 +215,19 @@ class InlineTest(unittest.TestCase):
     before_config = {
         'session_name': 'sampleconfig',
         'start_directory': '~',
-        'windows': [{
-            'shell_command': ['top'],
-            'window_name': 'editor',
-            'panes': [
-                {
-                    'start_directory': '~', 'shell_command': ['vim'],
+        'windows': [
+            {
+                'shell_command': ['top'],
+                'window_name': 'editor',
+                'panes': [
+                    {
+                        'start_directory': '~', 'shell_command': ['vim'],
                     },  {
-                    'shell_command': ['cowsay "hey"']
-                },
-            ],
-            'layout': 'main-verticle'},
+                        'shell_command': ['cowsay "hey"']
+                    },
+                ],
+                'layout': 'main-verticle'
+            },
             {
                 'window_name': 'logging',
                 'panes': [
@@ -222,27 +236,30 @@ class InlineTest(unittest.TestCase):
                 ]
             },
             {
-                'options': { 'automatic_rename': True, },
+                'options': {'automatic_rename': True, },
                 'panes': [
                     {'shell_command': ['htop']}
                 ]
-            }]
+            }
+        ]
     }
 
     after_config = {
         'session_name': 'sampleconfig',
         'start_directory': '~',
-        'windows': [{
-            'shell_command': 'top',
-            'window_name': 'editor',
-            'panes': [
-                {
-                    'start_directory': '~', 'shell_command': 'vim',
+        'windows': [
+            {
+                'shell_command': 'top',
+                'window_name': 'editor',
+                'panes': [
+                    {
+                        'start_directory': '~', 'shell_command': 'vim',
                     },  {
-                    'shell_command': 'cowsay "hey"'
-                },
-            ],
-            'layout': 'main-verticle'},
+                        'shell_command': 'cowsay "hey"'
+                    },
+                ],
+                'layout': 'main-verticle'
+            },
             {
                 'window_name': 'logging',
                 'panes': [
@@ -251,11 +268,12 @@ class InlineTest(unittest.TestCase):
                 ]
             },
             {
-                'options': { 'automatic_rename': True, },
+                'options': {'automatic_rename': True, },
                 'panes': [
                     {'shell_command': 'htop'}
                 ]
-            }]
+            }
+        ]
     }
 
     def test_config(self):
@@ -278,17 +296,19 @@ class InheritanceTest(unittest.TestCase):
     config_before = {
         'session_name': 'sampleconfig',
         'start_directory': '/',
-        'windows': [{
-            'window_name': 'editor',
-            'start_directory': '~',
-            'panes': [
-                {
-                    'start_directory': '~', 'shell_command': ['vim'],
+        'windows': [
+            {
+                'window_name': 'editor',
+                'start_directory': '~',
+                'panes': [
+                    {
+                        'start_directory': '~', 'shell_command': ['vim'],
                     },  {
-                    'shell_command': ['cowsay "hey"']
-                },
-            ],
-            'layout': 'main-verticle'},
+                        'shell_command': ['cowsay "hey"']
+                    },
+                ],
+                'layout': 'main-verticle'
+            },
             {
                 'window_name': 'logging',
                 'panes': [
@@ -303,27 +323,30 @@ class InheritanceTest(unittest.TestCase):
                 ]
             },
             {
-                'options': { 'automatic_rename': True, },
+                'options': {'automatic_rename': True, },
                 'panes': [
                     {'shell_command': ['htop']}
                 ]
-            }]
+            }
+        ]
     }
 
     config_after = {
         'session_name': 'sampleconfig',
         'start_directory': '/',
-        'windows': [{
-            'window_name': 'editor',
-            'start_directory': '~',
-            'panes': [
-                {
-                    'start_directory': '~', 'shell_command': ['vim'],
+        'windows': [
+            {
+                'window_name': 'editor',
+                'start_directory': '~',
+                'panes': [
+                    {
+                        'start_directory': '~', 'shell_command': ['vim'],
                     },  {
-                    'shell_command': ['cowsay "hey"'], 'start_directory': '~',
-                },
-            ],
-            'layout': 'main-verticle'},
+                        'shell_command': ['cowsay "hey"'], 'start_directory': '~',
+                    },
+                ],
+                'layout': 'main-verticle'
+            },
             {
                 'window_name': 'logging',
                 'panes': [
@@ -338,11 +361,12 @@ class InheritanceTest(unittest.TestCase):
                 ]
             },
             {
-                'options': { 'automatic_rename': True, },
+                'options': {'automatic_rename': True, },
                 'panes': [
                     {'shell_command': ['htop'], 'start_directory':'/'}
                 ]
-            }]
+            }
+        ]
     }
 
     def test_start_directory(self):
@@ -383,18 +407,20 @@ class ShellCommandBeforeTest(unittest.TestCase):
     config_unexpanded = {  # shell_command_before is string in some areas
         'session_name': 'sampleconfig',
         'start_directory': '/',
-        'windows': [{
-            'window_name': 'editor',
-            'start_directory': '~',
-            'shell_command_before': 'source .env/bin/activate',
-            'panes': [
-                {
-                    'start_directory': '~', 'shell_command': ['vim'],
+        'windows': [
+            {
+                'window_name': 'editor',
+                'start_directory': '~',
+                'shell_command_before': 'source .env/bin/activate',
+                'panes': [
+                    {
+                        'start_directory': '~', 'shell_command': ['vim'],
                     },  {
-                    'shell_command_before': ['rbenv local 2.0.0-p0'], 'shell_command': ['cowsay "hey"']
-                },
-            ],
-            'layout': 'main-verticle'},
+                        'shell_command_before': ['rbenv local 2.0.0-p0'], 'shell_command': ['cowsay "hey"']
+                    },
+                ],
+                'layout': 'main-verticle'
+            },
             {
                 'shell_command_before': 'rbenv local 2.0.0-p0',
                 'window_name': 'logging',
@@ -414,28 +440,31 @@ class ShellCommandBeforeTest(unittest.TestCase):
                 ]
             },
             {
-                'options': { 'automatic_rename': True, },
+                'options': {'automatic_rename': True, },
                 'panes': [
                     {'shell_command': ['htop']}
                 ]
-            }]
+            }
+        ]
     }
 
     config_expanded = {  # shell_command_before is string in some areas
         'session_name': 'sampleconfig',
         'start_directory': '/',
-        'windows': [{
-            'window_name': 'editor',
-            'start_directory': '~',
-            'shell_command_before': ['source .env/bin/activate'],
-            'panes': [
-                {
-                    'start_directory': '~', 'shell_command': ['vim'],
+        'windows': [
+            {
+                'window_name': 'editor',
+                'start_directory': '~',
+                'shell_command_before': ['source .env/bin/activate'],
+                'panes': [
+                    {
+                        'start_directory': '~', 'shell_command': ['vim'],
                     },  {
-                    'shell_command_before': ['rbenv local 2.0.0-p0'], 'shell_command': ['cowsay "hey"']
-                },
-            ],
-            'layout': 'main-verticle'},
+                        'shell_command_before': ['rbenv local 2.0.0-p0'], 'shell_command': ['cowsay "hey"']
+                    },
+                ],
+                'layout': 'main-verticle'
+            },
             {
                 'shell_command_before': ['rbenv local 2.0.0-p0'],
                 'window_name': 'logging',
@@ -455,28 +484,36 @@ class ShellCommandBeforeTest(unittest.TestCase):
                 ]
             },
             {
-                'options': { 'automatic_rename': True, },
+                'options': {'automatic_rename': True, },
                 'panes': [
                     {'shell_command': ['htop']}
                 ]
-            }]
+            }
+        ]
     }
 
     config_after = {  # shell_command_before is string in some areas
         'session_name': 'sampleconfig',
         'start_directory': '/',
-        'windows': [{
-            'window_name': 'editor',
-            'start_directory': '~',
-            'shell_command_before': ['source .env/bin/activate'],
-            'panes': [
-                {
-                    'start_directory': '~', 'shell_command': ['source .env/bin/activate', 'vim'],
+        'windows': [
+            {
+                'window_name': 'editor',
+                'start_directory': '~',
+                'shell_command_before': ['source .env/bin/activate'],
+                'panes': [
+                    {
+                        'start_directory': '~',
+                        'shell_command': ['source .env/bin/activate', 'vim'],
                     },  {
-                    'shell_command_before': ['rbenv local 2.0.0-p0'], 'shell_command': ['source .env/bin/activate', 'rbenv local 2.0.0-p0', 'cowsay "hey"']
-                },
-            ],
-            'layout': 'main-verticle'},
+                        'shell_command_before': ['rbenv local 2.0.0-p0'],
+                        'shell_command': [
+                            'source .env/bin/activate',
+                            'rbenv local 2.0.0-p0', 'cowsay "hey"'
+                        ]
+                    },
+                ],
+                'layout': 'main-verticle'
+            },
             {
                 'shell_command_before': ['rbenv local 2.0.0-p0'],
                 'window_name': 'logging',
@@ -500,7 +537,8 @@ class ShellCommandBeforeTest(unittest.TestCase):
                 'panes': [
                     {'shell_command': ['htop']}
                 ]
-            }]
+            }
+        ]
     }
 
     def test_shell_command_before(self):
